@@ -28,6 +28,7 @@
 
 static const gchar * const compatible_versions[] = {
         PACKAGE_VERSION, /* always list current version */
+	"2.2.4",
         "2.2.3",
 	"2.2.2",
 };
@@ -66,7 +67,7 @@ static void sensors_applet_gconf_error_occurred(SensorsAppletGConfError error) {
                                                     GTK_DIALOG_MODAL,
                                                     GTK_MESSAGE_WARNING,
                                                     GTK_BUTTONS_OK,
-                                                    markup);
+                                                    "%s", markup);
 
         g_free(markup);
 
